/*
 * SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
 *
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#pragma once

#include "linglong/api/dbus/v1/gen_org_deepin_linglong_packagemanager1.h"

namespace linglong::api::dbus::v1 {

using PackageManager = OrgDeepinLinglongPackageManager1Interface;

}
